Struct GitUrl
pub struct GitUrl {
pub host: Option<String>,
pub name: String,
pub owner: Option<String>,
pub organization: Option<String>,
pub fullname: String,
pub scheme: Scheme,
pub user: Option<String>,
pub token: Option<String>,
pub port: Option<u16>,
pub path: String,
pub git_suffix: bool,
pub scheme_prefix: bool,
}git2 or gitlab only.Expand description
GitUrl represents an input url that is a url used by git
Internally during parsing the url is sanitized and uses the url crate to perform
the majority of the parsing effort, and with some extra handling to expose
metadata used my many git hosting services
Fields
host: Option<String>The fully qualified domain name (FQDN) or IP of the repo
name: StringThe name of the repo
owner: Option<String>The owner/account/project name
organization: Option<String>The organization name. Supported by Azure DevOps
fullname: StringThe full name of the repo, formatted as โowner/nameโ
scheme: SchemeThe git url scheme
user: Option<String>The authentication user
token: Option<String>The oauth token (could appear in the https urls)
port: Option<u16>The non-conventional port where git service is hosted
path: StringThe path to repo w/ respect to user + hostname
git_suffix: boolIndicate if url uses the .git suffix
scheme_prefix: boolIndicate if url explicitly uses its scheme
Implementations